pub fn ensure_parent_dir(path: &str) -> Result<()>
Ensure the parent directory of path exists, creating it (and any missing ancestors) as needed. No-op when path has no parent or the parent is the current directory.
path